Installation
============

To install :mod:`audeer` run:

.. code-block:: bash

    $ # Create and activate Python virtual environment, e.g.
    $ # virtualenv --no-download --python=python3 ${HOME}/.envs/audeer
    $ # source ${HOME}/.envs/audeer/bin/activate
    $ pip install audeer
